#!/bin/sh

ACTION=${1}
shift 1

get_image() {
  IMAGE_NAME="nextcloud"
}

do_install() {
  get_image

  do_install_detail
}

do_install() {
  local config=`uci get nextcloud.@nextcloud[0].config_path 2>/dev/null`
  local port=`uci get nextcloud.@nextcloud[0].port 2>/dev/null`
  local IMAGE_NAME=`uci get nextcloud.@nextcloud[0].image_name 2>/dev/null`

  #Generate the generic environment variables for the docker-compose

  GEN_PASS=$(< /dev/urandom tr -dc A-Za-z0-9 2>/dev/null | head -c14; echo)
  GEN_PASS2=$(< /dev/urandom tr -dc A-Za-z0-9 2>/dev /null | head -c14; echo)

  # Get our local LAN IP Address
  LAN_IP=$(uci get network.lan.ipaddr)
  # Strip trailing network mask
  LAN_IP="${LAN_IP%/*}"


  if [ -z "$config" ]; then
      echo "config path is empty!"
      exit 1
  fi

    [ -z "$port" ] && port=8531
  [ -z "$IMAGE_NAME" ] && IMAGE_NAME=nextcloud:latest


  # Create Docker Compose file with custom variables

  # Create Docker Compose file with custom variables
touch docker-compose.yml
cat > docker-compose.yml <<EOF
version: '2'

volumes:
  nextcloud:
  db:

services:
  db:
    image: mariadb:10.5
    restart: always
    command: --transaction-isolation=READ-COMMITTED --binlog-format=ROW
    volumes:
      - db:/var/lib/mysql
    environment:
      - MYSQL_ROOT_PASSWORD=${GEN_PASS}
      - MYSQL_PASSWORD=${GEN_PASS}
      - MYSQL_DATABASE=nextcloud
      - MYSQL_USER=nextcloud

  app:
    image: nextcloud
    restart: always
    ports:
      - $port:80
    links:
      - db
    volumes:
      - ./data:/var/www/html
    environment:
      - MYSQL_PASSWORD=${GEN_PASS}
      - MYSQL_DATABASE=nextcloud
      - MYSQL_USER=nextcloud
      - MYSQL_HOST=db
    labels:
      plugsy.name: "Nextcloud"
      plugsy.category: "Home"
      plugsy.icon: "@styled-icons/material-outlined/Cloud"
      plugsy.link: "http://${LAN_IP}:$port"
EOF

  docker-compose up -d

  # Add a new list option to the "shortcutmenu" configuration file
  uci add shortcutmenu lists
  uci set shortcutmenu.@lists[-1].webname="$IMAGE_NAME"
  uci set shortcutmenu.@lists[-1].weburl="$LAN_IP:$port"
  uci set shortcutmenu.@lists[-1].webpath="/"
  uci commit shortcutmenu

}

usage() {
  echo "usage: $0 sub-command"
  echo "where sub-command is one of:"
  echo "      install                Install the nextcloud"
  echo "      upgrade                Upgrade the nextcloud"
  echo "      rm/start/stop/restart  Remove/Start/Stop/Restart the nextcloud"
  echo "      status                 Nextcloud status"
  echo "      port                   Nextcloud port"
}

case ${ACTION} in
  "install")
    do_install
  ;;
  "upgrade")
    do_install
  ;;
  "rm")
    docker rm -f nextcloud
  ;;
  "start" | "stop" | "restart")
    docker ${ACTION} nextcloud
  ;;
  "status")
    docker ps --all -f 'name=nextcloud' --format '{{.State}}'
  ;;
  "port")
    docker ps --all -f 'name=nextcloud' --format '{{.Ports}}' | grep -om1 '0.0.0.0:[0-9]*' | sed 's/0.0.0.0://'
  ;;
  *)
    usage
    exit 1
  ;;
esac
